@@ -5,7 +5,8 @@ import pytest
 
 
 @pytest.mark.parametrize('exit_status', [0, 1, 2, 32, 64, 127, 254, 255])
-def test_exit_status_regular_exit(exit_status, both_debug_modes, both_setsid_modes):
+@pytest.mark.usefixtures('both_debug_modes', 'both_setsid_modes')
+def test_exit_status_regular_exit(exit_status):
     """dumb-init should exit with the same exit status as the process that it
     supervises when that process exits normally.
     """
@@ -20,7 +21,8 @@ def test_exit_status_regular_exit(exit_status, both_debug_modes, both_setsid_mod
     signal.SIGQUIT,
     signal.SIGKILL,
 ])
-def test_exit_status_terminated_by_signal(signal, both_debug_modes, both_setsid_modes):
+@pytest.mark.usefixtures('both_debug_modes', 'both_setsid_modes')
+def test_exit_status_terminated_by_signal(signal):
     """dumb-init should exit with status 128 + signal when the child process is
     terminated by a signal.
     """
